# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: servicelayer/rpc/ocr.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from servicelayer.rpc import common_pb2 as servicelayer_dot_rpc_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='servicelayer/rpc/ocr.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1aservicelayer/rpc/ocr.proto\x1a\x1dservicelayer/rpc/common.proto\"y\n\x05Image\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x11\n\tlanguages\x18\x02 \x03(\t\x12\x19\n\x04mode\x18\x03 \x01(\x0e\x32\x0b.Image.Mode\"4\n\x04Mode\x12\t\n\x05OTHER\x10\x00\x12\x08\n\x04PAGE\x10\x01\x12\x08\n\x04WORD\x10\x02\x12\r\n\tCHARACTER\x10\x03\x32+\n\rRecognizeText\x12\x1a\n\tRecognize\x12\x06.Image\x1a\x05.Textb\x06proto3')
  ,
  dependencies=[servicelayer_dot_rpc_dot_common__pb2.DESCRIPTOR,])



_IMAGE_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='Image.Mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAGE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORD', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHARACTER', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=130,
  serialized_end=182,
)
_sym_db.RegisterEnumDescriptor(_IMAGE_MODE)


_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='Image.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='languages', full_name='Image.languages', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='Image.mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMAGE_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=182,
)

_IMAGE.fields_by_name['mode'].enum_type = _IMAGE_MODE
_IMAGE_MODE.containing_type = _IMAGE
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), dict(
  DESCRIPTOR = _IMAGE,
  __module__ = 'servicelayer.rpc.ocr_pb2'
  # @@protoc_insertion_point(class_scope:Image)
  ))
_sym_db.RegisterMessage(Image)



_RECOGNIZETEXT = _descriptor.ServiceDescriptor(
  name='RecognizeText',
  full_name='RecognizeText',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=184,
  serialized_end=227,
  methods=[
  _descriptor.MethodDescriptor(
    name='Recognize',
    full_name='RecognizeText.Recognize',
    index=0,
    containing_service=None,
    input_type=_IMAGE,
    output_type=servicelayer_dot_rpc_dot_common__pb2._TEXT,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RECOGNIZETEXT)

DESCRIPTOR.services_by_name['RecognizeText'] = _RECOGNIZETEXT

# @@protoc_insertion_point(module_scope)
